@@ -10,7 +10,7 @@ def deal(code):
     lang_name = code.split()[1][:-1]
     code = '\n'.join(code.split('\n')[1:-1])
     lexer = get_lexer_by_name(lang_name)
-    formatter = HtmlFormatter(linenos=True)
+    formatter = HtmlFormatter(linenos=False)
     return highlight(code, lexer, formatter)
 
 def highlight_txt(txt):   
